==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/Sffeb2f11864cbac67ddc15ceb7923faf.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
 
#ifdef macintosh
 
#pragma Sdcf15d3851e1b8c3d02afa9e565936b4 off
 
#endif
  void Sf9f3ee1653b211501e9d783e5c2119ef(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, NULL, "configuration_mode", 
"cm", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S4914cd007dbb4398d2d5e49e9fd83ae2, 
NULL, "entry_name", "en", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""))); 
 S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S6e140e2f2221b90042fef432e6d282eb, NULL, "number_thousands_divider", 
"ntd", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, 
NULL, "filters", "f", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""))); 
 S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, NULL, "session_information_filters", 
"sif", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "page_paths_page", "ppp", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(false, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, NULL, "get_hits", "gh", 
new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, 
NULL, "print_subitems", "ps", new S34c8bc3f549bc1db617d4ed83a8481b4(false), new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S21db3510045cc6255e7dffc9708664b3, NULL, "log_block_size", 
"lbs", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "generate_bookmark", "gb", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "internal_scratch_option", "iso", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, NULL, "expanded_edit_limits_items", 
"eeli", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "expanded_session_paths", "esp", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, NULL, "master_process_id", 
"mpi", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S1ddcb92ade31c8fbd370001f9b29a7d9, S2e73921d23514b94e0ed95cc5f40a3e5, 
NULL, "place_view_menu_at_top", "pvmat", new S34c8bc3f549bc1db617d4ed83a8481b4(false))); }

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/Sffeb2f11864cbac67ddc15ceb7923faf.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
 
#ifdef macintosh
 
#pragma Sdcf15d3851e1b8c3d02afa9e565936b4 off
 
#endif
  void Sf9f3ee1653b211501e9d783e5c2119ef(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, NULL, "configuration_mode", 
"cm", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S4914cd007dbb4398d2d5e49e9fd83ae2, 
NULL, "entry_name", "en", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""))); 
 S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S6e140e2f2221b90042fef432e6d282eb, NULL, "number_thousands_divider", 
"ntd", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, 
NULL, "filters", "f", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""))); 
 S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, NULL, "session_information_filters", 
"sif", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S6e140e2f2221b90042fef432e6d282eb, 
NULL, "extra_session_columns", "esc", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, NULL, "page_paths_page", 
"ppp", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(false, false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, 
NULL, "get_hits", "gh", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1a6a49bccf589a1244fe2e0d7874bd3d, 
NULL, "print_subitems", "ps", new S34c8bc3f549bc1db617d4ed83a8481b4(false), new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S21db3510045cc6255e7dffc9708664b3, NULL, "log_block_size", 
"lbs", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "generate_bookmark", "gb", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "internal_scratch_option", "iso", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, NULL, "expanded_edit_limits_items", 
"eeli", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, 
NULL, "expanded_session_paths", "esp", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sbc957e26ff41470c556ee5d09e96880b, S1886d290aa9d67039d4a58df2a537187, NULL, "master_process_id", 
"mpi", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S1ddcb92ade31c8fbd370001f9b29a7d9, S2e73921d23514b94e0ed95cc5f40a3e5, 
NULL, "place_view_menu_at_top", "pvmat", new S34c8bc3f549bc1db617d4ed83a8481b4(false))); }
